%define anolis_release 2

%global grub_version 2.06
%global fwupd_version 1.5.8
%global openssl_ver 1.0.2j

%ifarch x86_64
%global efiarch x64
%endif

%ifarch aarch64
%global efiarch aa64
%endif

%global efidir anolis
%global shimrootdir %{_datadir}/shim/
%global shimversiondir %{shimrootdir}/%{version}-%{release}
%global shimdir %{shimversiondir}/%{efiarch}

%global debug_package %{nil}
%global __debug_package 1
%global _binaries_in_noarch_packages_terminate_build 0
%global __debug_install_post %{SOURCE100} %{efiarch}
%undefine _debuginfo_subpackages

Name:           shim
Version:        15.7
Release:        %{anolis_release}%{?dist}
Summary:        First-stage UEFI bootloader
License:        BSD
URL:            https://github.com/rhboot/shim/
Source0:        https://github.com/rhboot/shim/releases/download/%{version}/shim-%{version}.tar.bz2
Source1:        shim.conf
Source100:      shim-find-debuginfo.sh

Patch0001:      0001-aarch64-Keep-_relocate-from-being-dirtied-by-_reloca.patch

BuildRequires:  efi-filesystem
BuildRequires:  efi-srpm-macros >= 5
BuildRequires:  gcc make dos2unix findutils git pesign
BuildRequires:  elfutils-libelf-devel openssl-devel

ExclusiveArch:  x86_64 aarch64

%description
Initial UEFI bootloader that handles chaining to a trusted full bootloader
under secure boot environments. This package contains the version signed by
the UEFI signing service.

%package -n shim-%{efiarch}
Summary:   First-stage UEFI bootloader
Requires:  mokutil >= 1:0.3.0
Requires:  efi-filesystem
Requires:  grub2-efi-%{efiarch} >= %{grub_version}

Provides:  shim-signed-%{efiarch} = %{version}-%{release}
Provides:  shim = %{version}-%{release}
Provides:  shim-signed = %{version}-%{release}
Provides:  bundled(openssl) = %{openssl_ver}

Conflicts: fwupd < %{fwupd_version}
Conflicts: grub2-efi-%{efiarch} < %{grub_version}

Obsoletes: shim-signed < %{version}-%{release}
Obsoletes: shim < %{version}-%{release}

%description -n shim-%{efiarch}
Initial UEFI bootloader that handles chaining to a trusted full
bootloader under secure boot environments. This package contains the
version signed by the UEFI signing service.

%package debuginfo
Summary:        Debug information for shim
AutoReqProv:    0

%description debuginfo
This package provides debug information for shim.
Debug information is useful when developing applications that
use this package or when debugging this package.

%package debugsource
Summary:        Debug Source for shim
AutoReqProv:    0

%description debugsource
This package provides debug sources for shim.
Debug information is useful when developing applications that 
use this package or when debugging this package.

%prep
%autosetup -S git -n shim-%{version}
git config --unset user.email
git config --unset user.name
mkdir build-%{efiarch}

%build
COMMITID=$(cat commit)
MAKEFLAGS="TOPDIR=.. -f ../Makefile COMMITID=${COMMITID} "
MAKEFLAGS+="EFIDIR=%{efidir} PKGNAME=shim RELEASE=%{release} "
MAKEFLAGS+="ENABLE_SHIM_HASH=true "
MAKEFLAGS+="%{_smp_mflags}"

pushd build-%{efiarch}
make ${MAKEFLAGS} DEFAULT_LOADER='\\\\grub%{efiarch}.efi' all
popd


%install
COMMITID=$(cat commit)
MAKEFLAGS="TOPDIR=.. -f ../Makefile COMMITID=${COMMITID} "
MAKEFLAGS+="EFIDIR=%{efidir} PKGNAME=shim RELEASE=%{release} "
MAKEFLAGS+="ENABLE_SHIM_HASH=true "

pushd build-%{efiarch}
make ${MAKEFLAGS} DEFAULT_LOADER='\\\\grub%{efiarch}.efi' DESTDIR=%{buildroot} \
        install-as-data install-debuginfo install-debugsource

install -D -d -m 0755 %{buildroot}/boot/
install -D -d -m 0700 %{buildroot}%{efi_esp_root}/
install -D -d -m 0700 %{buildroot}%{efi_esp_efi}/
install -D -d -m 0700 %{buildroot}%{efi_esp_dir}/
install -D -d -m 0700 %{buildroot}%{efi_esp_boot}/

# efi files are not signed now
install -m 0700 shim%{efiarch}.efi %{buildroot}%{efi_esp_dir}/
install -m 0700 mm%{efiarch}.efi %{buildroot}%{efi_esp_dir}/
install -m 0700 fb%{efiarch}.efi $RPM_BUILD_ROOT%{efi_esp_boot}/fb%{efiarch}.efi
install -m 0700 shim%{efiarch}.efi %{buildroot}%{efi_esp_dir}/shim.efi

%ifarch x86_64
install -m 0700 shimx64.efi $RPM_BUILD_ROOT%{efi_esp_boot}/BOOTX64.EFI
install -m 0700 BOOTX64.CSV $RPM_BUILD_ROOT%{efi_esp_dir}/
%endif

%ifarch aarch64
install -m 0700 shimaa64.efi $RPM_BUILD_ROOT%{efi_esp_boot}/BOOTAA64.EFI
install -m 0700 BOOTAA64.CSV $RPM_BUILD_ROOT%{efi_esp_dir}/
%endif

popd

install -m 0755 -D -d %{buildroot}%{_sysconfdir}/dnf/protected.d/
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/dnf/protected.d/

%files -n shim-%{efiarch}
%license COPYRIGHT
%{_sysconfdir}/dnf/protected.d/shim.conf
%dir %{shimrootdir}
%dir %{shimversiondir}
%dir %{shimdir}
%{shimdir}/*.CSV
%{shimdir}/*.efi
%{shimdir}/*.hash
%{efi_esp_dir}/*.CSV
%{efi_esp_dir}/*.efi
%{efi_esp_boot}/*.efi
%{efi_esp_boot}/*.EFI

%files debuginfo -f build-%{efiarch}/debugfiles.list

%files debugsource -f build-%{efiarch}/debugsource.list

%changelog
* Thu Apr 13 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 15.7-2
- optimise spec file
- replace shim-unsigned-x64/aa64

* Wed Feb 8 2023 Guyu Wang <guyu.wgy@linux.alibaba.com> - 15.7-1
- update package to 15.7

* Tue Mar 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 15.4-1
- init from upstream 15.4
